@@ -14,14 +14,18 @@ public class FileSelectorDemo {
 		Button okBtn=filew.getOKButton();
 		okBtn.addListener(new ButtonListener(){
 			public void buttonEvent(ButtonEvent evt){
-				System.out.println("Ok button pressed.");
+				if (evt.isOfType(ButtonEvent.Type.CLICK)) {
+					System.out.println("Ok button pressed.");
+					Gtk.mainQuit();
+				}
 			}
 		});
 
 		Button cancelBtn=filew.getCancelButton();
 		cancelBtn.addListener(new ButtonListener(){
 			public void buttonEvent(ButtonEvent evt){
-				System.out.println("Cancel button pressed");
+				if (evt.isOfType(ButtonEvent.Type.CLICK))
+					System.out.println("Cancel button pressed");
 			}
 		});
 			
@@ -29,10 +33,6 @@ public class FileSelectorDemo {
 		filew.show();
     }
 
-	public void fileOkSel() {
-		System.out.println(filew.getFilename());
-   }
-  
 	public static void main(String[] args) {
 		// Initialize GTK 
 		Gtk.init(args);
