@@ -8,13 +8,16 @@
  */
 
 package org.gnu.gdk;
+
+import org.gnu.glib.Handle;
+
 /**
  *
  */
 public class Bitmap extends Drawable 
 {
 	
-	public Bitmap(int handle){
+	public Bitmap(Handle handle){
 		super(handle);
 	}
 	
@@ -28,15 +31,10 @@ public class Bitmap extends Drawable
 	 * Creates a new <code>Bitmap</code> from data in XBM format.
 	 */
 	public Bitmap(byte data[],int width,int height){
-		super(Bitmap.gdk_bitmap_create_from_data(-1,data,width,height));
+		super(Bitmap.gdk_bitmap_create_from_data(null,data,width,height));
 	}
-    /****************************************
-     * BEGINNING OF GENERATED CODE
-     ****************************************/
-    native static final protected int gdk_bitmap_create_from_data (int window, byte[] data, int 
+
+    native static final protected Handle gdk_bitmap_create_from_data (Handle window, byte[] data, int 
         width, int height);
-    /****************************************
-     * END OF GENERATED CODE
-     ****************************************/
 }
 
