@@ -683,7 +683,9 @@ public class GObject {
         GObject obj = getGObjectFromHandle( gobject );
 
         PropertyNotificationListener listen = null;
-        ListIterator it = notifyListeners.listIterator();
+        if(notifyListeners == null)
+			notifyListeners = new ArrayList();
+		ListIterator it = notifyListeners.listIterator();
         while( it.hasNext() ) {
             listen = (PropertyNotificationListener)it.next();
             listen.notify( obj, propname );
@@ -715,17 +717,27 @@ public class GObject {
      * pointer to an int ( gint* ).  This method dereferences that
      * pointer and returns the value to which it points as an integer.
      *
-     * @param inthandle The native Handle holding a pointer to an int.
+     * @param handle The native Handle holding a pointer to an int.
      * @return The int that is pointed to by the native Handle.
      */
-    native static final protected int getIntFromHandle(Handle inthandle);
+    native static final protected int getIntFromHandle(Handle handle);
+    /**
+     * Return the String to which the native {@link org.gnu.glib.Handle}
+     * holds a pointer.  The native Handle is assumed to hold a C
+     * pointer to a String (char* ).  This method dereferences that
+     * pointer and returns the value to which it points as a String.
+     *
+     * @param handle The native Handle holding a pointer to a String.
+     * @return The String that is pointed to by the native Handle.
+     */
+    native static final protected String getStringFromHandle(Handle handle);
 
     //native static final public void setTestProperty(Handle object, String prop, Handle obj);
 
     // ------------------------------------------------------------------------
     // static init code
     static {
-        System.loadLibrary("gtkjni-" + org.gnu.glib.Config.GTK_API_VERSION);
+        System.loadLibrary(org.gnu.glib.Config.LIBRARY_NAME + org.gnu.glib.Config.GTK_API_VERSION);
         registerLogHandler();
     }
 
