@@ -167,7 +167,7 @@ public class Expander extends Bin {
 	    Handle hndl = gtk_expander_get_label_widget(getHandle());
 		if (null == hndl)
 			return null;
-		GObject obj = retrieveGObject(hndl);
+		GObject obj = getGObjectFromHandle(hndl);
 		if (null != obj)
 			return (Widget)obj;
 		return new Widget(hndl);
