@@ -12,6 +12,7 @@ package org.gnu.gtk;
 import org.gnu.glib.GObject;
 import org.gnu.glib.Handle;
 import org.gnu.glib.Type;
+import org.gnu.pango.EllipsizeMode;
 
 /**
  * The Label widget displays a small amount of text. As the name implies, most 
@@ -242,7 +243,7 @@ public class Label extends Misc {
 	 */
 	public Widget getMnemonicWidget() {
 	    Handle hndl = gtk_label_get_mnemonic_widget(getHandle());
-		GObject obj = retrieveGObject(hndl);
+		GObject obj = getGObjectFromHandle(hndl);
 		if (null != obj)
 			return (Widget)obj;
 		return new Widget(hndl);
@@ -375,7 +376,7 @@ public class Label extends Misc {
 	/**
 	 * Retrieves the desired width of label, in characters. 
 	 *
-	 * @see #SetWidthChars(int)
+	 * @see #setWidthChars(int)
 	 * @return the width of the label in characters.
 	 * @since 2.6 
 	 */
@@ -396,7 +397,7 @@ public class Label extends Misc {
 	/** 
 	 * Retrieves the desired maximum width of label, in characters. 
 	 *
-	 * @see #SetMaxWidthChars(int)
+	 * @see #setMaxWidthChars(int)
 	 * @return the maximum width of the label in characters.
 	 * @since 2.6
 	 */
@@ -421,7 +422,7 @@ public class Label extends Misc {
 	/** 
 	 * Gets the angle of rotation for the label. 
 	 *
-	 * @see #SetAngle(double)
+	 * @see #setAngle(double)
 	 * @return	the angle of rotation for the label
 	 * @since 2.6 
 	 */
@@ -447,7 +448,22 @@ public class Label extends Misc {
 		return gtk_label_get_single_line_mode(getHandle());
 	}
 
-
+    /**
+     * Sets the mode used to ellipsize (add an ellipsis: "...") the
+     * text if there is not enough space to render the entire string.
+     * @since 2.6 
+     */
+    public void setEllipsize( EllipsizeMode mode ) {
+        gtk_label_set_ellipsize( getHandle(), mode.getValue() );
+    }
+    /**
+     * Returns the ellipsizing position.
+     * @since 2.6 
+     */
+    public EllipsizeMode getEllipsize() {
+        return EllipsizeMode.intern( gtk_label_get_ellipsize( getHandle() ) );
+    }
+    
 	/**
 	 * Retrieve the runtime type used by the GLib library.
 	 */
@@ -494,6 +510,11 @@ public class Label extends Misc {
     native static final private double gtk_label_get_angle(Handle label);
     native static final private void gtk_label_set_single_line_mode(Handle label, boolean single_line_mode);
     native static final private boolean gtk_label_get_single_line_mode(Handle label);
+    native static final private void gtk_label_set_ellipsize(Handle label, int mode);
+    native static final private int gtk_label_get_ellipsize(Handle label);
 
-
+    /* Deprecated functions.
+    native static final private void gtk_label_get(Handle label, char** str);
+    native static final private int gtk_label_parse_uline(Handle label, String string);
+    */
 }
