@@ -9,10 +9,11 @@
 
 package org.gnu.gtk;
 
-import org.gnu.glib.GObject;
+import org.gnu.glib.Boxed;
+import org.gnu.glib.Handle;
 
 /**
- * Defination for sources and destinations of Drag and Drop operations.
+ * Definition for sources and destinations of Drag and Drop operations.
  *
  * If a drag and drop is allowed between a pair of widgets, they must have the
  * same TargetEntry in their drop source and destination lists. 
@@ -20,7 +21,7 @@ import org.gnu.glib.GObject;
  *
  * TODO: Free the memory !!
  */
-public class TargetEntry extends GObject
+public class TargetEntry extends Boxed
 {
 	/**
 	 * Constructs a new target entry
@@ -35,7 +36,7 @@ public class TargetEntry extends GObject
 		super(newTargetEntry(name, flags.getValue(), id));
 	}
 
-	native static protected final int newTargetEntry( String name, int flags, int id );
+	native static protected final Handle newTargetEntry( String name, int flags, int id );
 
 }
 
