@@ -14,6 +14,7 @@ import java.util.Vector;
 import org.gnu.glib.EventMap;
 import org.gnu.glib.EventType;
 import org.gnu.glib.GObject;
+import org.gnu.glib.Handle;
 import org.gnu.glib.Type;
 import org.gnu.glib.Value;
 import org.gnu.gtk.event.TreeModelEvent;
@@ -33,7 +34,7 @@ public class TreeModel extends GObject {
 
 	/**
 	 */
-	protected TreeModel(int handle) {
+	protected TreeModel(Handle handle) {
 		super(handle);
 	}
 
@@ -61,7 +62,7 @@ public class TreeModel extends GObject {
 	 * <code>null</code>/
 	 */
 	public TreeIter getIter(TreePath path) {
-		int hndl = gtk_tree_model_get_iter(getHandle(), path.getHandle());
+	    Handle hndl = gtk_tree_model_get_iter(getHandle(), path.getHandle());
 		return iterFromHandle(hndl);
 	}
 
@@ -71,7 +72,7 @@ public class TreeModel extends GObject {
 	 * invalid.
 	 */
 	public TreeIter getIter(String pathString) {
-		int hndl = gtk_tree_model_get_iter_from_string(getHandle(), pathString);
+	    Handle hndl = gtk_tree_model_get_iter_from_string(getHandle(), pathString);
 		return iterFromHandle(hndl);
 	}
 
@@ -80,7 +81,7 @@ public class TreeModel extends GObject {
 	 * or returns <code>null</code> if the tree is empty.
 	 */
 	public TreeIter getFirstIter() {
-		int hndl = gtk_tree_model_get_iter_first(getHandle());
+	    Handle hndl = gtk_tree_model_get_iter_first(getHandle());
 		return iterFromHandle(hndl);
 	}
 
@@ -88,7 +89,7 @@ public class TreeModel extends GObject {
 	 * Returns the Value at the given iter in the specified data block. 
 	 */
 	public String getValue(TreeIter iter, DataColumnString dataBlock) {
-		int value = gtk_tree_model_get_value(getHandle(), iter.getHandle(), dataBlock.getColumn());
+	    Handle value = gtk_tree_model_get_value(getHandle(), iter.getHandle(), dataBlock.getColumn());
 		Value val = new Value(value);
 		return val.getString();
 	}
@@ -96,7 +97,7 @@ public class TreeModel extends GObject {
 	 * Returns the Value at the given iter in the specified data block.
 	 */
 	public int getValue(TreeIter iter, DataColumnInt dataBlock) {
-		int value = gtk_tree_model_get_value(getHandle(), iter.getHandle(), dataBlock.getColumn());
+	    Handle value = gtk_tree_model_get_value(getHandle(), iter.getHandle(), dataBlock.getColumn());
 		Value val = new Value(value);
 		return val.getInt();
 	}
@@ -104,7 +105,7 @@ public class TreeModel extends GObject {
 	 * Returns the Value at the given iter in the specified data block. 
 	 */
 	public boolean getValue(TreeIter iter, DataColumnBoolean dataBlock) {
-		int value = gtk_tree_model_get_value(getHandle(), iter.getHandle(), dataBlock.getColumn());
+	    Handle value = gtk_tree_model_get_value(getHandle(), iter.getHandle(), dataBlock.getColumn());
 		Value val = new Value(value);
 		return val.getBoolean();
 	}
@@ -112,7 +113,7 @@ public class TreeModel extends GObject {
 	 * Returns the Value at the given iter in the specified data block. 
 	 */
 	public double getValue(TreeIter iter, DataColumnDouble dataBlock) {
-		int value = gtk_tree_model_get_value(getHandle(), iter.getHandle(), dataBlock.getColumn());
+	    Handle value = gtk_tree_model_get_value(getHandle(), iter.getHandle(), dataBlock.getColumn());
 		Value val = new Value(value);
 		return val.getDouble();
 	}
@@ -120,13 +121,13 @@ public class TreeModel extends GObject {
 	 * Returns the Value at the given iter in the specified data block. 
 	 */
 	public Object getValue(TreeIter iter, DataColumnObject dataBlock) {
-		int value = gtk_tree_model_get_value(getHandle(), iter.getHandle(), dataBlock.getColumn());
+	    Handle value = gtk_tree_model_get_value(getHandle(), iter.getHandle(), dataBlock.getColumn());
 		Value val = new Value(value);
 		return val.getJavaObject();
 	}
 
-	private TreeIter iterFromHandle(int hndl) {
-		if (-1 == hndl)
+	private TreeIter iterFromHandle(Handle hndl) {
+		if (null == hndl)
 			return null;
 		return new TreeIter(hndl, this);
 	}
@@ -203,36 +204,34 @@ public class TreeModel extends GObject {
 		}
 	}
 
-	private void handleRowChanged(int path, int iter) {
+	private void handleRowChanged(Handle path, Handle iter) {
 		TreeModelEvent event = new TreeModelEvent(this, TreeModelEvent.Type.ROW_CHANGED);
 		event.setTreePath(new TreePath(path));
 		event.setTreeIter(new TreeIter(iter, this));
 		fireTreeModelEvent(event);
 	}
 
-	private void handleRowInserted(int path, int iter) {
+	private void handleRowInserted(Handle path, Handle iter) {
 		TreeModelEvent event = new TreeModelEvent(this, TreeModelEvent.Type.ROW_INSERTED);
 		event.setTreePath(new TreePath(path));
 		event.setTreeIter(new TreeIter(iter, this));
 		fireTreeModelEvent(event);
 	}
 
-	private void handleRowHasChildToggled(int path, int iter) {
+	private void handleRowHasChildToggled(Handle path, Handle iter) {
 		TreeModelEvent event = new TreeModelEvent(this, TreeModelEvent.Type.ROW_HAS_CHILD_TOGGLED);
 		event.setTreePath(new TreePath(path));
 		event.setTreeIter(new TreeIter(iter, this));
 		fireTreeModelEvent(event);
 	}
 
-	private void handleRowDeleted(int path) {
+	private void handleRowDeleted(Handle path) {
 		TreeModelEvent event = new TreeModelEvent(this, TreeModelEvent.Type.ROW_DELETED);
 		event.setTreePath(new TreePath(path));
 		fireTreeModelEvent(event);
 	}
 
-	private void handleRowsReordered(int path, int iter, int newOrder) {
-		System.out.println("Handle rows reordered");
-		System.err.println("Handle rows reordered");
+	private void handleRowsReordered(Handle path, Handle iter, Handle newOrder) {
 		TreeModelEvent event = new TreeModelEvent(this, TreeModelEvent.Type.ROWS_REORDERED);
 		event.setTreePath(new TreePath(path));
 		event.setTreeIter(new TreeIter(iter, this));
@@ -270,29 +269,23 @@ public class TreeModel extends GObject {
 	}
 
 	
-	/****************************************
-	 * BEGINNING OF JNI CODE
-	 ****************************************/
-    native static final protected int gtk_tree_model_get_n_columns(int treeModel);
-    native static final protected int gtk_tree_model_get_column_type(int treeModel, int index);
-    native static final protected int gtk_tree_model_get_iter(int treeModel, int path);
-    native static final protected int gtk_tree_model_get_iter_from_string(int treeModel, String pathString);
-    native static final protected String gtk_tree_model_get_string_from_iter(int treeModel, int iter);
-    native static final protected int gtk_tree_model_get_iter_first(int treeModel);
-    native static final protected int gtk_tree_model_get_path(int treeModel, int iter);
-    native static final protected int gtk_tree_model_get_value(int treeModel, int iter, int column);
-    native static final protected int gtk_tree_model_iter_next(int treeModel, int iter);
-    native static final protected int gtk_tree_model_iter_children(int treeModel, int parent);
-    native static final protected boolean gtk_tree_model_iter_has_child(int treeModel, int iter);
-    native static final protected int gtk_tree_model_iter_n_children(int treeModel, int iter);
-    native static final protected int gtk_tree_model_iter_nth_child(int treeModel, int parent, int n);
-    native static final protected int gtk_tree_model_iter_parent(int treeModel, int child);
+    native static final protected int gtk_tree_model_get_n_columns(Handle treeModel);
+    native static final protected int gtk_tree_model_get_column_type(Handle treeModel, int index);
+    native static final protected Handle gtk_tree_model_get_iter(Handle treeModel, Handle path);
+    native static final protected Handle gtk_tree_model_get_iter_from_string(Handle treeModel, String pathString);
+    native static final protected String gtk_tree_model_get_string_from_iter(Handle treeModel, Handle iter);
+    native static final protected Handle gtk_tree_model_get_iter_first(Handle treeModel);
+    native static final protected Handle gtk_tree_model_get_path(Handle treeModel, Handle iter);
+    native static final protected Handle gtk_tree_model_get_value(Handle treeModel, Handle iter, int column);
+    native static final protected Handle gtk_tree_model_iter_next(Handle treeModel, Handle iter);
+    native static final protected Handle gtk_tree_model_iter_children(Handle treeModel, Handle parent);
+    native static final protected boolean gtk_tree_model_iter_has_child(Handle treeModel, Handle iter);
+    native static final protected int gtk_tree_model_iter_n_children(Handle treeModel, Handle iter);
+    native static final protected Handle gtk_tree_model_iter_nth_child(Handle treeModel, Handle parent, int n);
+    native static final protected Handle gtk_tree_model_iter_parent(Handle treeModel, Handle child);
 //    native static final protected void gtk_tree_model_row_changed(int treeModel, int path, int iter);
 //    native static final protected void gtk_tree_model_row_inserted(int treeModel, int path, int iter);
 //    native static final protected void gtk_tree_model_row_has_child_toggled(int treeModel, int path, int iter);
 //    native static final protected void gtk_tree_model_row_deleted(int treeModel, int path);
 //    native static final protected void gtk_tree_model_rows_reordered(int treeModel, int path, int iter, int[] newOrder); 
-	/****************************************
-	 * END OF JNI CODE
-	 ****************************************/
 }
