@@ -227,7 +227,6 @@ public class TreeView extends Container {
 	
 	/**
 	 * Returns true if the headers on the TreeView are visible.
-	 * @return
 	 */
 	public boolean getHeadersVisible() {
 		return gtk_tree_view_get_headers_visible(getHandle());
@@ -802,7 +801,9 @@ public class TreeView extends Container {
 
 	private void handleRowActivated(Handle path, Handle column) {
 		TreeViewEvent event = new TreeViewEvent(this, TreeViewEvent.Type.ROW_ACTIVATED);
-		event.setTreePath(new TreePath(path));
+		TreePath aPath = new TreePath(path);
+		event.setTreePath(aPath);
+		event.setTreeIter(this.getModel().getIter(aPath));
 		GObject obj = getGObjectFromHandle(column);
 		if (null != obj)
 			event.setTreeColumn((TreeViewColumn)obj);
