@@ -30,7 +30,7 @@ public class Window extends Bin {
 	/**
 	 * Construct a new Window object.
 	 * 
-	 * @param type The type of window to create
+	 * @param windowType The type of window to create
 	 */
 	public Window(WindowType windowType) {
 		super(Window.gtk_window_new(windowType.getValue()));
@@ -52,7 +52,11 @@ public class Window extends Bin {
 	 * @param title A string containing the title for this Window
 	 */
 	public void setTitle(String title) {
+            if ( title != null ) {
 		Window.gtk_window_set_title(getHandle(), title);
+            } else {
+		Window.gtk_window_set_title(getHandle(), "");
+            }
 	}
 
 	/**
@@ -164,7 +168,7 @@ public class Window extends Bin {
 	    Handle hndl = gtk_window_get_focus(getHandle());
 		if (null == hndl)
 			return null;
-		GObject obj = retrieveGObject(hndl);
+		GObject obj = getGObjectFromHandle( hndl );
 		if (null != obj)
 			return (Widget)obj;
 		return new Widget(hndl);
@@ -319,6 +323,58 @@ public class Window extends Bin {
 	public void setIcon(Pixbuf icon) {
 		Window.gtk_window_set_icon(getHandle(), icon.getHandle());
 	}
+	
+	/**
+	 * Returns the icon representing the Window.
+	 */
+	public Pixbuf getIcon() {
+		Handle hndl = gtk_window_get_icon(getHandle());
+		GObject obj = getGObjectFromHandle(hndl);
+		if (null != obj)
+			return (Pixbuf)obj;
+		return new Pixbuf(hndl);
+		
+	}
+	
+	/**
+	 * Sets up the icon representing a GtkWindow. The icon is 
+	 * used when the window is minimized (also known as iconified). 
+	 * Some window managers or desktop environments may also place 
+	 * it in the window frame, or display it in other contexts.
+	 * 
+	 * setIconList allows you to pass in the same icon in several 
+	 * hand-drawn sizes. The list should contain the natural sizes 
+	 * your icon is available in; that is, don't scale the image 
+	 * before passing it.  Scaling is postponed until the last minute, 
+	 * when the desired final size is known, to allow best quality.
+	 * 
+	 * By passing several sizes, you may improve the final image 
+	 * quality of the icon, by reducing or eliminating automatic 
+	 * image scaling.
+	 * 
+	 * Recommended sizes to provide: 16x16, 32x32, 48x48 at minimum, 
+	 * and larger images (64x64, 128x128) if you have them.
+	 */
+	public void setIconList(Pixbuf[] icons) {
+		Handle[] hndls = new Handle[icons.length];
+		for (int i = 0; i < icons.length; i++)
+			hndls[i] = icons[i].getHandle();
+		gtk_window_set_icon_list(getHandle(), hndls);
+	}
+	
+	/**
+	 * Retrieves the list of icons set by setIconList(). The list is 
+	 * copied, but the reference count on each member won't be incremented.
+	 */
+	public Pixbuf[] getIconList() {
+		Handle[] hndls = gtk_window_get_icon_list(getHandle());
+		if (hndls == null)
+			return null;
+		Pixbuf[] pix = new Pixbuf[hndls.length];
+		for (int i = 0; i < hndls.length; i++) 
+			pix[i] = new Pixbuf(hndls[i]);
+		return pix;
+	}
 
 	/**
 	 * Set to true to keep this window from appearing in the task bar.
@@ -330,7 +386,6 @@ public class Window extends Bin {
 	
 	/**
 	 * Returns whether this window should appear in the task bar.
-	 * @return
 	 */
 	public boolean getSkipTaskbarHint() {
 		return gtk_window_get_skip_taskbar_hint(getHandle());
@@ -346,7 +401,6 @@ public class Window extends Bin {
 
 	/**
 	 * Returns whether the window should appear in the pager.
-	 * @return
 	 */
 	public boolean getSkipPagerHint() {
 		return gtk_window_get_skip_pager_hint(getHandle());
@@ -359,31 +413,76 @@ public class Window extends Bin {
 	public boolean getAcceptFocus() {
 		return gtk_window_get_accept_focus(getHandle());
 	}
+	
+	/**
+	 * Sets the Screen where the window is displayed; if the window is already 
+	 * mapped, it will be unmapped, and then remapped on the new screen.
+	 * @param screen the new screen.
+	 */
 
 	public void setScreen(Screen screen) {
 		gtk_window_set_screen(getHandle(), screen.getHandle());
 	}
+	
+	/**
+	 * Returns the GdkScreen associated with this window.
+	 */
 
 	public Screen getScreen() {
 	    Handle hndl = gtk_window_get_screen(getHandle());
-		GObject obj = retrieveGObject(hndl);
+		GObject obj = getGObjectFromHandle(hndl);
 		if (null != obj)
 			return (Screen)obj;
 		return new Screen(hndl);
 	}
+	
+	/**
+	 * Returns whether the window is part of the current active toplevel. 
+	 * (That is, the toplevel window receiving keystrokes.) The return value 
+	 * is TRUE if the window is active toplevel itself, but also if it is, say, 
+	 * a {@link Plug} embedded in the active toplevel. You might use this 
+	 * method if you wanted to draw a widget differently in an active window 
+	 * from a widget in an inactive window.
+	 * 
+	 */
 
 	public boolean isActive() {
 		return gtk_window_is_active(getHandle());
 	}
 	
+	/**
+	 * Returns whether the input focus is within this Window. For real toplevel 
+	 * windows, this is identical to <code>isActive()</code>, but for embedded
+	 * windows, like {@link Plug}, the results will differ.
+	 */
+	
 	public boolean hasToplevelFocus() {
 		return gtk_window_has_toplevel_focus(getHandle());
 	}
 
+	/**
+	 * Sets the icon for this window.
+	 * 
+	 * @param filename the full path to the icon
+	 * @return <code>true</code> if the icon was sucessfully set, 
+	 * <code>false</code> otherwise. 
+	 */
+	
 	public boolean setIconFromFile(String filename) {
 		return gtk_window_set_icon_from_file(getHandle(), filename);
 	}
 	
+	/**
+	 * Sets an icon to be used as fallback for windows that haven't had 
+	 * setIconList() called on them from a file on disk. 
+	 * 
+	 * @see #setIconName(String)
+	 * 
+	 * @param filename the path to the icon
+	 * @return <code>true</code> if it was sucessfully set, 
+	 * <code>false</code> otherwise.
+	 */
+
 	public static boolean setDefaultIconFromFile(String filename) {
 		return gtk_window_set_default_icon_from_file(filename);
 	}
@@ -412,6 +511,30 @@ public class Window extends Bin {
 		gtk_window_set_keep_below(getHandle(), setting);
 	}
 	
+	/**
+	 * Sets up the icon representing a Window. The icon is used when the 
+	 * window is minimized (also known as iconified). Some window managers or 
+	 * desktop environments may also place it in the window frame, or display 
+	 * it in other contexts.
+	 * 
+	 * This method allows you to pass in the same icon in several 
+	 * hand-drawn sizes. The list should contain the natural sizes your icon is 
+	 * available in; that is, don't scale the image before passing it to GTK+. 
+	 * Scaling is postponed until the last minute, when the desired final size 
+	 * is known, to allow best quality.
+	 * 
+	 * By passing several sizes, you may improve the final image quality of the 
+	 * icon, by reducing or eliminating automatic image scaling.
+	 * 
+	 * Recommended sizes to provide: 16x16, 32x32, 48x48 at minimum, and larger
+	 * images (64x64, 128x128) if you have them.
+	 * 
+	 * Note that this method sets the icon for all windows in your application 
+	 * in one go.
+	 * 
+	 * @param icons the list of icons to use.
+	 */
+	
 	public static void setDefaultIconList(Pixbuf[] icons) {
 		if (null == icons)
 			return;
@@ -422,6 +545,12 @@ public class Window extends Bin {
 		gtk_window_set_default_icon_list(hndls);
 	}
 	
+	/**
+	 * Gets the icons set by <code>setDefaultIconList</code>.
+	 * 
+	 * @return the list of icons
+	 */
+	
 	public static Pixbuf[] getDefaultIconList() {
 	    Handle[] hndls = gtk_window_get_default_icon_list();
 		Pixbuf[] pbs = new Pixbuf[hndls.length];
@@ -431,6 +560,12 @@ public class Window extends Bin {
 		return pbs;
 	}
 	
+	/**
+	 * Returns a list of all existing toplevel windows.
+	 * 
+	 * @return the array containing the windows
+	 */
+	
 	public static Window[] listToplevelWindows() {
 	    Handle[] hndls = gtk_window_list_toplevels();
 		Window[] wins = new Window[hndls.length];
@@ -478,8 +613,12 @@ public class Window extends Bin {
     public String getIconName() {
         return gtk_window_get_icon_name( getHandle() );
     }
+    
     /**
-     *
+     * Sets an icon to be used as fallback for windows that haven't had 
+     * <code>setIconList</code> called on them from a named themed icon.
+     *  
+     * @see #setIconName(String)
      */
     public void setDefaultIconName( String name ) {
         gtk_window_set_default_icon_name( name );
@@ -524,8 +663,8 @@ public class Window extends Bin {
 	native static final protected void gtk_window_get_frame_dimensions(Handle window, int[] left, int[] top, int[] right, int[] bottom);
 	native static final protected void gtk_window_set_decorated(Handle window, boolean setting);
 	native static final protected boolean gtk_window_get_decorated(Handle window);
-	native static final protected void gtk_window_set_icon_list(Handle window, Handle list);
-	native static final protected Handle gtk_window_get_icon_list(Handle window);
+	native static final protected void gtk_window_set_icon_list(Handle window, Handle[] list);
+	native static final protected Handle[] gtk_window_get_icon_list(Handle window);
 	native static final protected void gtk_window_set_icon(Handle window, Handle icon);
 	native static final protected Handle gtk_window_get_icon(Handle window);
 	native static final protected void gtk_window_set_default_icon_list(Handle[] list);
