@@ -14,6 +14,8 @@
 
 package org.gnu.gtk.event;
 
+import org.gnu.glib.EventType;
+
 
 /**
  * An event represeting action by a {@link org.gnu.gtk.CellRendererToggle} widget.
@@ -22,7 +24,7 @@ package org.gnu.gtk.event;
  */
 public class CellRendererToggleEvent extends GtkEvent {
 
-	public static class Type extends GtkEventType{
+	public static class Type extends EventType{
 		private Type(int id, String name){
 			super(id, name);
 		}
