@@ -355,8 +355,8 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gdk_Pixbuf_gdk_1pixbuf_1get_1file_1info
   (JNIEnv *env, jclass cls, jstring filename, jintArray width, jintArray height)
 {
     const gchar* filename_g = (*env)->GetStringUTFChars(env, filename, 0);
-	gint* w = (*env)->GetIntArrayElements(env, width, NULL);
-	gint* h = (*env)->GetIntArrayElements(env, height, NULL);
+	gint* w = (gint*)(*env)->GetIntArrayElements(env, width, NULL);
+	gint* h = (gint*)(*env)->GetIntArrayElements(env, height, NULL);
 	jobject handle = getHandleFromPointer(env, gdk_pixbuf_get_file_info(filename_g, w, h));
 	(*env)->ReleaseIntArrayElements(env, width, (jint*)w, 0);
 	(*env)->ReleaseIntArrayElements(env, height, (jint*)h, 0);
@@ -393,7 +393,8 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gdk_Pixbuf_gdk_1pixbuf_1new_1from_1inline
     GError* error_g = NULL;
     (*env)->GetByteArrayRegion(env, data, 0, data_len, (jbyte*)data_g);
     data_g[data_len] = 0;
-    jobject handle = gdk_pixbuf_new_from_inline (dataLength_g, data_g, copyPixels_g, &error_g);
+    jobject handle = getHandleFromPointer(env, 
+    	gdk_pixbuf_new_from_inline (dataLength_g, data_g, copyPixels_g, &error_g));
     if (NULL != error_g)
     	updateHandle(env, error, error_g);
     return handle;
