@@ -400,8 +400,7 @@ jobject createNewBooleanInstance(JNIEnv *env, jboolean boolean_j) {
  */
 jobject getEnumInstance(JNIEnv *env, GValue *value_g) {
     char *enumClassName = javaobject_from_gtktype(G_VALUE_TYPE(value_g));
-    printf("Enum-derived class: %s\n", enumClassName);
-    const char *internSignature = g_malloc(64);
+    char *internSignature = g_malloc(64);
 
     jclass enumClass = (*env)->FindClass(env, enumClassName);
     if (enumClass == NULL)
@@ -411,7 +410,7 @@ jobject getEnumInstance(JNIEnv *env, GValue *value_g) {
                     "intern", internSignature);
     if (internMethod == NULL)
         return (jobject) NULL;
-    return (*env)->CallStaticIntMethod(env, enumClass, internMethod,
+    return (*env)->CallStaticObjectMethod(env, enumClass, internMethod,
                     (jint) g_value_get_enum(value_g));
 }
 
@@ -474,6 +473,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_glib_Value_g_1value_1get_1java_1object (J
     return getHandleFromPointer(env, pointer_g);
 }
 
+
 /*
  * Class:     org.gnu.glib.Value
  * Method:    g_value_set_pointer
@@ -496,6 +496,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_glib_Value_g_1value_1get_1pointer (JNIEnv
     return getHandleFromPointer(env, pointer_g);
 }
 
+
 #ifdef __cplusplus
 }
 
