@@ -8,8 +8,8 @@
  */
 
 #include <jni.h>
-#include <sys/types.h>
 #include <gtk/gtk.h>
+#include "jg_jnu.h"
 
 #ifndef _Included_org_gnu_gtk_ActionEntry
 #define _Included_org_gnu_gtk_ActionEntry
@@ -23,105 +23,103 @@ void handleCallbackAction(GtkAction* action, gpointer userData);
 /*
  * Class:     org_gnu_gtk_ActionEntry
  * Method:    allocate
- * Signature: ()I
  */
-JNIEXPORT jint JNICALL Java_org_gnu_gtk_ActionEntry_allocate
+JNIEXPORT jobject JNICALL Java_org_gnu_gtk_ActionEntry_allocate
   (JNIEnv *env, jclass cls)
 {
 	GtkActionEntry* entry = (GtkActionEntry*)g_malloc(sizeof(GtkActionEntry));
 	entry->callback = G_CALLBACK(handleCallbackAction);
-	return (jint)entry;
+	return getHandleFromPointer(env, entry);
 }
 
 /*
  * Class:     org_gnu_gtk_ActionEntry
  * Method:    free
- * Signature: (I)V
  */
 JNIEXPORT void JNICALL Java_org_gnu_gtk_ActionEntry_free
-  (JNIEnv *env, jclass cls, jint entry)
+  (JNIEnv *env, jclass cls, jobject entry)
 {
-	GtkActionEntry* e = (GtkActionEntry*)entry;
+	GtkActionEntry* e = (GtkActionEntry*)getPointerFromHandle(env, entry);
 	g_free(e);
 }
 
 /*
  * Class:     org_gnu_gtk_ActionEntry
  * Method:    setName
- * Signature: (ILjava/lang/String;)V
  */
 JNIEXPORT void JNICALL Java_org_gnu_gtk_ActionEntry_setName
-  (JNIEnv *env, jclass cls, jint entry, jstring name)
+  (JNIEnv *env, jclass cls, jobject entry, jstring name)
 {
+	GtkActionEntry* e = (GtkActionEntry*)getPointerFromHandle(env, entry);
 	if (NULL == name) {
-		((GtkActionEntry*)entry)->name = NULL;
+		e->name = NULL;
 	} else {
 		gchar* n = (gchar*)(*env)->GetStringUTFChars(env, name, NULL);
-		((GtkActionEntry*)entry)->name = n;
+		e->name = n;
 	}
 }
 
 /*
  * Class:     org_gnu_gtk_ActionEntry
  * Method:    setStockId
- * Signature: (ILjava/lang/String;)V
  */
 JNIEXPORT void JNICALL Java_org_gnu_gtk_ActionEntry_setStockId
-  (JNIEnv *env, jclass cls, jint entry, jstring value)
+  (JNIEnv *env, jclass cls, jobject entry, jstring value)
 {
+	GtkActionEntry* e = (GtkActionEntry*)getPointerFromHandle(env, entry);
 	if (NULL == value) {
-		((GtkActionEntry*)entry)->stock_id = NULL;
+		e->stock_id = NULL;
 	} else {
 		gchar* v = (gchar*)(*env)->GetStringUTFChars(env, value, NULL);
-		((GtkActionEntry*)entry)->stock_id = v;
+		e->stock_id = v;
 	}
 }
 
 /*
  * Class:     org_gnu_gtk_ActionEntry
  * Method:    setLabel
- * Signature: (ILjava/lang/String;)V
  */
 JNIEXPORT void JNICALL Java_org_gnu_gtk_ActionEntry_setLabel
-  (JNIEnv *env, jclass cls, jint entry, jstring value)
+  (JNIEnv *env, jclass cls, jobject entry, jstring value)
 {
+	GtkActionEntry* e = (GtkActionEntry*)getPointerFromHandle(env, entry);
 	if (NULL == value) {
-		((GtkActionEntry*)entry)->label = NULL;
+		e->label = NULL;
 	} else {
 		gchar* v = (gchar*)(*env)->GetStringUTFChars(env, value, NULL);
-		((GtkActionEntry*)entry)->label = v;
+		e->label = v;
 	}
 }
 
 /*
  * Class:     org_gnu_gtk_ActionEntry
  * Method:    setAccelerator
- * Signature: (ILjava/lang/String;)V
  */
 JNIEXPORT void JNICALL Java_org_gnu_gtk_ActionEntry_setAccelerator
-  (JNIEnv *env, jclass cls, jint entry, jstring value)
+  (JNIEnv *env, jclass cls, jobject entry, jstring value)
 {
+	GtkActionEntry* e = (GtkActionEntry*)getPointerFromHandle(env, entry);
 	if (NULL == value) {
-		((GtkActionEntry*)entry)->accelerator = NULL;
+		e->accelerator = NULL;
 	} else {
 		gchar* v = (gchar*)(*env)->GetStringUTFChars(env, value, NULL);
-		((GtkActionEntry*)entry)->accelerator = v;
+		e->accelerator = v;
 	}
 }
 
 /*
  * Class:     org_gnu_gtk_ActionEntry
  * Method:    setToolTtip
- * Signature: (ILjava/lang/String;)V
  */
 JNIEXPORT void JNICALL Java_org_gnu_gtk_ActionEntry_setToolTip
-  (JNIEnv *env, jclass cls, jint entry, jstring value)
+  (JNIEnv *env, jclass cls, jobject entry, jstring value)
 {
+	GtkActionEntry* e = (GtkActionEntry*)getPointerFromHandle(env, entry);
 	if (NULL == value) {
-		((GtkActionEntry*)entry)->tooltip = NULL;
+		e->tooltip = NULL;
 	} else {
 		gchar* v = (gchar*)(*env)->GetStringUTFChars(env, value, NULL);
-		((GtkActionEntry*)entry)->tooltip = v;
+		e->tooltip = v;
 	}
 }
 
