@@ -34,7 +34,7 @@ static void internalHandleActionCallback(gpointer action, CallbackInfo *cbi)
 		return;
 	}
 
-	jargs->l = (jobject)action;
+	jargs->l = getHandleFromPointer(cbi->env, action);
 	(* cbi->env)->CallVoidMethodA(cbi->env, cbi->obj, cbi->methodID, jargs);
 }
 
