@@ -157,7 +157,7 @@ JNIEXPORT void JNICALL Java_org_gnu_gtk_Box_gtk_1box_1query_1child_1packing (JNI
     (*env)->ReleaseBooleanArrayElements(env, expand, (jboolean *)expand_g, 0);
     (*env)->ReleaseBooleanArrayElements(env, fill, (jboolean *)fill_g, 0);
     (*env)->ReleaseIntArrayElements (env, padding, (jint *) padding_g, 0);
-    (*env)->ReleaseIntArrayElements (env, packType, packType_g_g, 0);
+    (*env)->ReleaseIntArrayElements (env, packType, (jint *)packType_g_g, 0);
 }
 
 /*
