@@ -794,6 +794,21 @@ JNIEXPORT void JNICALL Java_org_gnu_gtk_TextView_gtk_1text_1view_1set_1overwrite
     gtk_text_view_set_overwrite( textView_g, setting_g );
 }
 
+/* GTK 2.6 additions. */
+
+JNIEXPORT jboolean JNICALL Java_org_gnu_gtk_TextBuffer_gtk_1text_1buffer_1backspace
+(JNIEnv *env, jclass cls, jobject buffer, jobject iter, jboolean interactive, jboolean default_editable)
+{
+    GtkTextBuffer * buffer_g = 
+        (GtkTextBuffer *)getPointerFromHandle(env, buffer);
+    GtkTextIter * iter_g = (GtkTextIter *)getPointerFromHandle(env, iter);
+    gboolean interactive_g = (gboolean)interactive;
+    gboolean default_editable_g = (gboolean)default_editable;
+    return (jboolean)gtk_text_buffer_backspace(buffer_g, iter_g, 
+                                               interactive_g, 
+                                               default_editable_g);
+}
+
 #ifdef __cplusplus
 }
 
