@@ -415,10 +415,11 @@ JNIEXPORT jboolean JNICALL Java_org_gnu_gtk_Window_gtk_1window_1get_1decorated (
  * Method:    gtk_window_set_icon_list
  * Signature: (II)V
  */
-JNIEXPORT void JNICALL Java_org_gnu_gtk_Window_gtk_1window_1set_1icon_1list (JNIEnv *env, jclass cls, jobject window, jobject list) 
+JNIEXPORT void JNICALL Java_org_gnu_gtk_Window_gtk_1window_1set_1icon_1list 
+	(JNIEnv *env, jclass cls, jobject window, jobjectArray list) 
 {
     GtkWindow *window_g = (GtkWindow *)getPointerFromHandle(env, window);
-    GList *list_g = (GList *)getPointerFromHandle(env, list);
+    GList *list_g = (GList *)getGListFromHandles(env, list);
     gtk_window_set_icon_list (window_g, list_g);
 }
 
@@ -427,10 +428,10 @@ JNIEXPORT void JNICALL Java_org_gnu_gtk_Window_gtk_1window_1set_1icon_1list (JNI
  * Method:    gtk_window_get_icon_list
  * Signature: (I)I
  */
-JNIEXPORT jobject JNICALL Java_org_gnu_gtk_Window_gtk_1window_1get_1icon_1list (JNIEnv *env, jclass cls, jobject window) 
+JNIEXPORT jobjectArray JNICALL Java_org_gnu_gtk_Window_gtk_1window_1get_1icon_1list (JNIEnv *env, jclass cls, jobject window) 
 {
     GtkWindow *window_g = (GtkWindow *)getPointerFromHandle(env, window);
-    return getHandleFromPointer(env, gtk_window_get_icon_list (window_g));
+    return getHandleArrayFromGList(env, gtk_window_get_icon_list (window_g));
 }
 
 /*
